/**
 * Copyright (c) 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api;

import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycleFactory;
import org.ow2.petals.admin.api.conf.ArtifactUrlRewriter;
import org.ow2.petals.admin.api.exception.ConnectionFailedException;
import org.ow2.petals.admin.api.exception.ContainerAdministrationException;
import org.ow2.petals.admin.api.exception.NoConnectionException;

/**
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface PetalsAdministration {

    public void connect(String host, int port, String user, String password)
            throws ContainerAdministrationException, ConnectionFailedException;

    /**
     * @return <code>true</code> if connected to a Petals ESB container, <code>false</code> otherwise.
     * @throws ContainerAdministrationException
     *             An error occurs checking the connection.
     */
    public boolean isConnected() throws ContainerAdministrationException;

    /**
     * @throws NoConnectionException
     *             There is no current JMX connection to the remote petals ESB.
     * @throws ContainerAdministrationException
     *             An error occurs releasing the connection.
     */
    public void disconnect() throws NoConnectionException, ContainerAdministrationException;

    /**
     * Create instance of {@link ArtifactAdministration} implementation.
     * 
     * @return an {@link ArtifactAdministration} instance.
     */
    public abstract ArtifactAdministration newArtifactAdministration();

    /**
     * Create instance of {@link ArtifactAdministration} implementation.
     * 
     * @param artifactUrlRewriter
     *            an url rewriter for deployments
     * @return an {@link ArtifactAdministration} instance.
     */
    public abstract ArtifactAdministration newArtifactAdministration(final ArtifactUrlRewriter artifactUrlRewriter);

    /**
     * Create instance of {@link ContainerAdministration} implementation.
     * 
     * @return a {@link ContainerAdministration} instance.
     */
    public abstract ContainerAdministration newContainerAdministration();

    /**
     * Create instance of {@link EndpointDirectoryAdministration} implementation.
     * 
     * @return a {@link EndpointDirectoryAdministration} instance.
     */
    public abstract EndpointDirectoryAdministration newEndpointDirectoryAdministration();

    /**
     * Create instance of {@link ArtifactLifecycleFactory} implementation.
     * 
     * @param artifactUrlRewriter
     *            an url rewriter for deployments
     * @return an {@link ArtifactLifecycleFactory} instance.
     */
    public abstract ArtifactLifecycleFactory newArtifactLifecycleFactory(final ArtifactUrlRewriter artifactUrlRewriter);

    /**
     * Create instance of {@link ArtifactLifecycleFactory} implementation.
     * 
     * @return an {@link ArtifactLifecycleFactory} instance.
     */
    public abstract ArtifactLifecycleFactory newArtifactLifecycleFactory();
}
