/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.artifact.lifecycle;

import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.SharedLibrary;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;

public abstract class ArtifactLifecycleFactory {

    /**
     * Create an artifact lifecycle introspecting the artifact.
     * 
     * @param artifact
     *            The artifact for which a lifecycle must be created
     * @return The lifecycle of the artifact.
     * @throws UncheckedException
     *             Unknown artifact type
     */
    public final ArtifactLifecycle createLifecycle(final Artifact artifact)
            throws UncheckedException {

        if (artifact instanceof Component) {
            return this.createComponentLifecycle((Component) artifact);
        } else if (artifact instanceof ServiceAssembly) {
            return this.createServiceAssemblyLifecycle((ServiceAssembly) artifact);
        } else if (artifact instanceof SharedLibrary) {
            return this.createSharedLibraryLifecycle((SharedLibrary) artifact);
        } else {
            throw new UncheckedException("Unknow artifact type: " + (artifact == null ? null : artifact.getType()));
        }
    }

    public abstract ComponentLifecycle createComponentLifecycle(final Component c);

    public abstract ServiceAssemblyLifecycle createServiceAssemblyLifecycle(final ServiceAssembly sa);

    public abstract SharedLibraryLifecycle createSharedLibraryLifecycle(final SharedLibrary sl);
}
