/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.conf;

import java.net.URL;

import org.ow2.petals.admin.api.exception.ArtifactUrlRewriterException;

/**
 * An artifact URL rewriter transforms the URL of an artifact to another one. The main use case of such
 * {@link ArtifactUrlRewriter} is the deployment of local artifact using URL 'file':
 * <ul>
 * <li>the artifact URL with protocol 'file' ...</li>
 * <li>... is rewritten into an URL with protocol 'http' ...</li>
 * <li>... so the Petals ESB container can download the artifact from a HTTP server embedded by the Petals
 * administration API client.</li>
 * </ul>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface ArtifactUrlRewriter {

    public static final ArtifactUrlRewriter NOOP = new ArtifactUrlRewriter() {
        @Override
        public URL rewrite(URL artifactUrl) throws ArtifactUrlRewriterException {
            return artifactUrl;
        }
    };

    /**
     * Transforms the URL of an artifact to another one.
     * 
     * @param artifactUrl
     *            The artifact URL to transform
     * @return The rewritten artifact URL
     * @throws ArtifactUrlRewriterException
     *             An error occurs rewriting the artifact URL
     */
    public URL rewrite(final URL artifactUrl) throws ArtifactUrlRewriterException;

}
