/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.topology;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * 
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class Domain {

    private final String name;

    private final List<Container> containers;

    public Domain(String name) {
        assert name != null;
        
        this.name = name;
        this.containers = new ArrayList<>();
    }

    public String getName() {
        return name;
    }
    
    /**
     * Add the containers of the given list to the domain.
     * 
     * @param containers
     */
    public void addContainers(List<Container> containers) {
        assert containers != null;

        this.containers.addAll(containers);
    }
    
    public void addContainers(Container... containers) {
        addContainers(Arrays.asList(containers));
    }

    public List<Container> getContainers() {
        return Collections.unmodifiableList(this.containers);
    }

    @Override
    public String toString() {
        return "Domain[" + this.name + "]";
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((name == null) ? 0 : name.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        Domain other = (Domain) obj;
        if (name == null) {
            if (other.name != null)
                return false;
        } else if (!name.equals(other.name))
            return false;
        return true;
    }
}
