/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api;

import java.net.URL;
import java.util.List;

import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.SharedLibrary;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycleFactory;
import org.ow2.petals.admin.api.artifact.lifecycle.ComponentLifecycle;
import org.ow2.petals.admin.api.artifact.lifecycle.ServiceAssemblyLifecycle;
import org.ow2.petals.admin.api.artifact.lifecycle.SharedLibraryLifecycle;
import org.ow2.petals.admin.api.conf.ArtifactUrlRewriter;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactDeployedException;
import org.ow2.petals.admin.api.exception.ArtifactNotDeployedException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactStartedException;
import org.ow2.petals.admin.api.exception.ArtifactStoppedException;
import org.ow2.petals.admin.api.exception.ArtifactTypeIsNeededException;
import org.ow2.petals.admin.api.exception.ArtifactUnsupportedOperationException;
import org.ow2.petals.admin.api.exception.ContainerAdministrationException;
import org.ow2.petals.admin.api.exception.NoConnectionException;
import org.ow2.petals.admin.api.exception.UnsupportedArtifactTypeException;

/**
 * A mock of Petals Administration API implementation used to unit test the classes of Petals Administration API
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class PetalsAdministrationMock implements PetalsAdministration {

    private final List<Artifact> artifacts;

    private class ArtifactAdministrationMock extends ArtifactAdministration {

        private final List<Artifact> artifacts;

        protected ArtifactAdministrationMock(final List<Artifact> artifacts,
                final ArtifactUrlRewriter artifactUrlRewriter) {
            super(PetalsAdministrationMock.this, artifactUrlRewriter);
            this.artifacts = artifacts;
        }

        @Override
        public void stopAndUndeployAllArtifacts() throws ArtifactAdministrationException {
            // NOP
        }

        @Override
        public List<Artifact> listArtifacts() throws ArtifactAdministrationException {
            return null;
        }

        @Override
        public Artifact getArtifact(final String type, final String name, final String version)
                throws UnsupportedArtifactTypeException, ArtifactNotFoundException,
                ArtifactTypeIsNeededException, ArtifactAdministrationException {

            for (final Artifact artifact : this.artifacts) {
                if (name.equals(artifact.getName()) && type.equals(artifact.getType())
                        && ((version == null && artifact.getVersion() == null)
                        		|| (version != null && version.equals(artifact.getVersion())))) {
                    return artifact;
                }
            }
            throw new ArtifactNotFoundException(type, name, version);
        }

    }

    private class ComponentLifecycleMock implements ComponentLifecycle {

        public ComponentLifecycleMock() {
            // NOP
        }

        @Override
        public void deploy(final URL artifactUrl) throws ArtifactDeployedException,
                ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void deploy(URL artifactUrl, boolean skipInstall)
                throws ArtifactDeployedException, ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void install() throws ArtifactNotFoundException, ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void uninstall()
                throws ArtifactNotDeployedException, ArtifactNotFoundException, ArtifactAdministrationException {
            // TODO Auto-generated method stub

        }

        @Override
        public void start() throws ArtifactStartedException, ArtifactNotDeployedException,
                ArtifactNotFoundException, ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void stop() throws ArtifactStoppedException, ArtifactNotDeployedException,
                ArtifactNotFoundException, ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void undeploy() throws ArtifactStartedException, ArtifactNotFoundException,
                ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void updateState() throws ArtifactAdministrationException {
            // NOP
        }

        @Override
        public Component getComponent() {
            return null;
        }

        @Override
        public void reloadConfiguration() throws ArtifactNotFoundException, ArtifactUnsupportedOperationException,
                ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void setParameters() {
            // NOP
        }

        @Override
        public void updateStateAndParameters() {
            // NOP
        }

    }

    private class ServiceAssemblyLifecycleMock implements ServiceAssemblyLifecycle {

        public ServiceAssemblyLifecycleMock() {
            // NOP
        }

        @Override
        public void deploy(final URL artifactUrl) throws ArtifactDeployedException,
                ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void start() throws ArtifactStartedException, ArtifactNotDeployedException,
                ArtifactNotFoundException, ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void stop() throws ArtifactStoppedException, ArtifactNotDeployedException,
                ArtifactNotFoundException, ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void undeploy() throws ArtifactStartedException, ArtifactNotFoundException,
                ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void updateState() throws ArtifactAdministrationException {
            // NOP
        }

        @Override
        public ServiceAssembly getServiceAssembly() {
            return null;
        }

    }

    private class SharedLibraryLifecycleMock implements SharedLibraryLifecycle {

        public SharedLibraryLifecycleMock() {
            // NOP
        }

        @Override
        public void deploy(final URL artifactUrl) throws ArtifactDeployedException,
                ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void start() throws ArtifactStartedException, ArtifactNotDeployedException,
                ArtifactNotFoundException, ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void stop() throws ArtifactStoppedException, ArtifactNotDeployedException,
                ArtifactNotFoundException, ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void undeploy() throws ArtifactStartedException, ArtifactNotFoundException,
                ArtifactAdministrationException {
            // NOP
        }

        @Override
        public void updateState() throws ArtifactAdministrationException {
            // NOP
        }

        @Override
        public SharedLibrary getSharedLibrary() {
            return null;
        }

    }

    private class ArtifactLifecycleFactoryMock extends ArtifactLifecycleFactory {

        @Override
        public ComponentLifecycle createComponentLifecycle(final Component c) {
            return new ComponentLifecycleMock();
        }

        @Override
        public ServiceAssemblyLifecycle createServiceAssemblyLifecycle(final ServiceAssembly sa) {
            return new ServiceAssemblyLifecycleMock();
        }

        @Override
        public SharedLibraryLifecycle createSharedLibraryLifecycle(final SharedLibrary sl) {
            return new SharedLibraryLifecycleMock();
        }

    }

    public PetalsAdministrationMock(final List<Artifact> artifacts) {
        this.artifacts = artifacts;
    }

    @Override
    public void connect(String host, int port, String user, String password) throws ContainerAdministrationException {
        // NOP
    }

    @Override
    public void disconnect() throws NoConnectionException, ContainerAdministrationException {
        // NOP
    }

    @Override
    public boolean isConnected() throws ContainerAdministrationException {
        return false;
    }

    @Override
    public ArtifactAdministration newArtifactAdministration() {
        return new ArtifactAdministrationMock(this.artifacts, ArtifactUrlRewriter.NOOP);
    }

    @Override
    public ArtifactAdministration newArtifactAdministration(ArtifactUrlRewriter artifactUrlRewriter) {
        return newArtifactAdministration();
    }

    @Override
    public ContainerAdministration newContainerAdministration() {
        return null;
    }

    @Override
    public EndpointDirectoryAdministration newEndpointDirectoryAdministration() {
        return null;
    }

    @Override
    public ArtifactLifecycleFactory newArtifactLifecycleFactory(ArtifactUrlRewriter artifactUrlRewriter) {
        return new ArtifactLifecycleFactoryMock();
    }

    @Override
    public ArtifactLifecycleFactory newArtifactLifecycleFactory() {
        return new ArtifactLifecycleFactoryMock();
    }
}
